Tutorials
~~~~~~~~~

We present a few tutorials of different levels. The blog building
tutorial introduces one smoothly to the basic concepts.

Then there is a photo gallery construction tutorial which highlights
more advanced concepts such as unit tests, security settings,
migration scripts.

.. toctree::
   :maxdepth: 1

   base/index
   advanced/index
   tools/windmill.rst
   textreports/index
   dataimport/index
